[evolution-mapi/gnome-3-6] Bug #685882 - NspiGetIDsFromNames failure with MAPI_E_NO_SUPPORT



commit 24c20518d1ecfdc3b3a90e13e099a61c46da6a5f
Author: Milan Crha <mcrha redhat com>
Date:   Thu Feb 21 20:37:55 2013 +0100

    Bug #685882 - NspiGetIDsFromNames failure with MAPI_E_NO_SUPPORT

 src/libexchangemapi/e-mapi-connection.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/libexchangemapi/e-mapi-connection.c b/src/libexchangemapi/e-mapi-connection.c
index b88e967..7fa0aaf 100644
--- a/src/libexchangemapi/e-mapi-connection.c
+++ b/src/libexchangemapi/e-mapi-connection.c
@@ -5348,8 +5348,8 @@ e_mapi_connection_resolve_named_props  (EMapiConnection *conn,
                                }
                        }
 
-                       /* 2010 server can return call_failed when didn't find any properties */
-                       if (ms == MAPI_E_CALL_FAILED)
+                       /* 2010 server can return call_failed or no_support when didn't find any properties */
+                       if (ms == MAPI_E_CALL_FAILED || ms == MAPI_E_NO_SUPPORT)
                                ms = MAPI_E_NOT_FOUND;
 
                        if (ms == MAPI_E_NOT_FOUND || ms == MAPI_E_SUCCESS) {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]